@@ -9,7 +9,6 @@
  */
 namespace PHPUnit\TextUI\Configuration;
 
-use function assert;
 use function count;
 use Iterator;
 
@@ -55,8 +54,6 @@ final class ConstantCollectionIterator implements Iterator
 
     public function current(): Constant
     {
-        assert(isset($this->constants[$this->position]));
-
         return $this->constants[$this->position];
     }
 
