@@ -9,7 +9,6 @@
  */
 namespace PHPUnit\TextUI\Configuration;
 
-use function assert;
 use function count;
 use Iterator;
 
@@ -55,8 +54,6 @@ final class ExtensionBootstrapCollectionIterator implements Iterator
 
     public function current(): ExtensionBootstrap
     {
-        assert(isset($this->extensionBootstraps[$this->position]));
-
         return $this->extensionBootstraps[$this->position];
     }
 
