@@ -7,21 +7,16 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+namespace PHPUnit\TestFixture;
+
+use Exception;
 use PHPUnit\Framework\TestCase;
 
-/*
- * This file is part of PHPUnit.
- *
- * (c) Sebastian Bergmann <sebastian@phpunit.de>
- *
- * For the full copyright and license information, please view the LICENSE
- * file that was distributed with this source code.
- */
 class Issue2145Test extends TestCase
 {
     public static function setUpBeforeClass(): void
     {
-        throw new Exception;
+        throw new Exception('message');
     }
 
     public function testOne(): void
