@@ -36,12 +36,23 @@ final class LogicalXorTest extends TestCase
                 true,
             ],
 
+            [
+                true,
+                'is false xor is equal to true',
+                '',
+                self::logicalXor(
+                    self::isFalse(),
+                    true,
+                ),
+                true,
+            ],
+
             [
                 true,
                 'is of type bool xor is true',
                 '',
                 self::logicalXor(
-                    self::isType('bool'),
+                    self::isBool(),
                     self::isTrue(),
                 ),
                 false,
@@ -52,7 +63,7 @@ final class LogicalXorTest extends TestCase
                 'is of type bool xor is true',
                 'Failed asserting that true is of type bool xor is true.',
                 self::logicalXor(
-                    self::isType('bool'),
+                    self::isBool(),
                     self::isTrue(),
                 ),
                 true,
@@ -64,11 +75,11 @@ final class LogicalXorTest extends TestCase
                 'Failed asserting that true is of type bool and is true xor is of type bool and is true.',
                 self::logicalXor(
                     self::logicalAnd(
-                        self::isType('bool'),
+                        self::isBool(),
                         self::isTrue(),
                     ),
                     self::logicalAnd(
-                        self::isType('bool'),
+                        self::isBool(),
                         self::isTrue(),
                     ),
                 ),
@@ -101,8 +112,8 @@ final class LogicalXorTest extends TestCase
     public function testIsCountable(): void
     {
         $constraint = $this->logicalXor(
-            $this->isType('bool'),
-            $this->isTrue(),
+            $this->isBool(),
+            true,
         );
 
         $this->assertCount(2, $constraint);
